summaryrefslogtreecommitdiff
path: root/libavcodec/jfdctfst.c
diff options
context:
space:
mode:
Diffstat (limited to 'libavcodec/jfdctfst.c')
-rw-r--r--libavcodec/jfdctfst.c18
1 files changed, 9 insertions, 9 deletions
diff --git a/libavcodec/jfdctfst.c b/libavcodec/jfdctfst.c
index 3e30e5d535..b2e41f107e 100644
--- a/libavcodec/jfdctfst.c
+++ b/libavcodec/jfdctfst.c
@@ -136,17 +136,17 @@
#endif
/* Multiply a DCTELEM variable by an int32_t constant, and immediately
* descale to yield a DCTELEM result.
*/
-#define MULTIPLY(var,const) ((DCTELEM) DESCALE((var) * (const), CONST_BITS))
+#define MULTIPLY(var,const) ((int16_t) DESCALE((var) * (const), CONST_BITS))
-static av_always_inline void row_fdct(DCTELEM * data){
+static av_always_inline void row_fdct(int16_t * data){
int tmp0, tmp1, tmp2, tmp3, tmp4, tmp5, tmp6, tmp7;
int tmp10, tmp11, tmp12, tmp13;
int z1, z2, z3, z4, z5, z11, z13;
- DCTELEM *dataptr;
+ int16_t *dataptr;
int ctr;
/* Pass 1: process rows. */
@@ -205,12 +205,12 @@ static av_always_inline void row_fdct(DCTELEM * data){
*/
GLOBAL(void)
-ff_fdct_ifast (DCTELEM * data)
+ff_fdct_ifast (int16_t * data)
{
int tmp0, tmp1, tmp2, tmp3, tmp4, tmp5, tmp6, tmp7;
int tmp10, tmp11, tmp12, tmp13;
int z1, z2, z3, z4, z5, z11, z13;
- DCTELEM *dataptr;
+ int16_t *dataptr;
int ctr;
row_fdct(data);
@@ -271,12 +271,12 @@ ff_fdct_ifast (DCTELEM * data)
*/
GLOBAL(void)
-ff_fdct_ifast248 (DCTELEM * data)
+ff_fdct_ifast248 (int16_t * data)
{
int tmp0, tmp1, tmp2, tmp3, tmp4, tmp5, tmp6, tmp7;
int tmp10, tmp11, tmp12, tmp13;
int z1;
- DCTELEM *dataptr;
+ int16_t *dataptr;
int ctr;
row_fdct(data);
@@ -136,17 +136,17 @@
#endif
-/* Multiply a DCTELEM variable by an int32_t constant, and immediately
- * descale to yield a DCTELEM result.
+/* Multiply a int16_t variable by an int32_t constant, and immediately
+ * descale to yield a int16_t result.
*/